PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - t -

- target : CloneEnv
- Temperature : Policy::CommonParams
- Termination : Action::Result
- TimeLine : ResultCollection
- TimeMicroseconds : ResultRecord
- TimeStep : ResultRecord
- Tolerance : Policy::CommonParams
- TrackLen : RouterResult
- TrackRasterCount : NavRasterizeParams
- Tracks : Palette
- tracks : dsn::Connection
- TrackWidthHalf : NavSpacings
- TRANSPARENT : Color
- TriangulationVisible : UserSettings
- type : dsn::Layer, dsn::Padstack, UIActions